@@ -94,14 +94,13 @@ conjdbc=function(trat,
   anova=c()
   tukey=c()
   graficos=list()
-  qmres=data.frame(QM=NA)
-
+  nlocal=length(levels(local))
+  qmres=data.frame(QM=1:nlocal)
   for(i in 1:length(levels(local))){
     anova[[i]]=anova(aov(resp~tratamento+bloco,
                          data=dados[dados$local==levels(dados$local)[i],]))
     qm=anova[[i]]$`Mean Sq`[3]
-    qmres[i,]=c(qm)
-    qmres=as.vector(qmres)
+    qmres[i,1]=c(qm)
     names(anova)[i]=levels(local)[i]
     aov1=aov(resp~tratamento+bloco, data=dados[dados$local==levels(dados$local)[i],])}
   matriza=matrix(rep(qmres[[1]],e=length(qmres[[1]])),
@@ -246,7 +245,6 @@ conjdbc=function(trat,
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   cat(green(bold("Analysis of variance")))
   cat(green(bold("\n-----------------------------------------------------------------\n")))
-  #print(b$`Error: local:tratamento`)
   print(as.matrix(datas),na.print = "")
   cat(green(bold("\n-----------------------------------------------------------------\n")))
 
@@ -258,10 +256,6 @@ conjdbc=function(trat,
     for(i in 1:length(levels(local))){
         anova1=anova(aov(resp~tratamento+bloco,
                              data=dados[dados$local==levels(dados$local)[i],]))
-        qm=anova1$`Mean Sq`[3]
-        qmres[i,]=c(qm)
-        qmres=as.vector(qmres)
-        #names(anova1)[i]=levels(local)[i]
         aov1=aov(resp~tratamento+bloco, data=dados[dados$local==levels(dados$local)[i],])
         if(quali==TRUE){
           if(mcomp=="tukey"){tukey[[i]]=TUKEY(aov1,"tratamento",
@@ -276,12 +270,17 @@ conjdbc=function(trat,
           if(mcomp=="sk"){
             anova=anova(aov1)
             data=dados[dados$local==levels(dados$local)[i],]
-            tukey[[i]]=sk(data$resp,
-                                 data$tratamento,
-                                 anova$Df[3],
-                                 anova$`Sum Sq`[3],alpha = alpha.t)[unique(as.character(trat)),]
-            comp=sk(data$resp,data$tratamento,anova$Df[3],
-                           anova$`Sum Sq`[3],alpha = alpha.t)}
+            nrep=table(data$trat)[1]
+            medias=sort(tapply(data$resp,data$trat,mean),decreasing = TRUE)
+            letra=scottknott(means = medias,
+                             df1 = anova$Df[2],
+                             nrep = nrep,
+                             QME = anova$`Mean Sq`[2],
+                             alpha = alpha.t)
+            letra1=data.frame(resp=medias,groups=letra)[unique(as.character(trat)),]
+            tukey[[i]]=letra1
+            comp=letra1
+            }
 
           if(transf=="1"){}else{tukey[[i]]$respo=with(dados[dados$local==levels(dados$local)[i],],
                                                       tapply(response, tratamento, mean, na.rm=TRUE))[rownames(comp)]}
@@ -318,13 +317,12 @@ conjdbc=function(trat,
                   axis.text = element_text(size=textsize,color="black", family = family),
                   legend.position = "none")
           graficos[[i]]=grafico}
-        print(graficos)
     }
       print(tukey)}
       if(quali==FALSE){
         for(i in 1:length(levels(local))){
         data=dados[dados$local==levels(dados$local)[i],]
-        dose1=data$tratnum#as.numeric(as.character(data$tratamento))
+        dose1=data$tratnum
         resp=data$response
         grafico=polynomial(dose1,
                            resp,grau = grau,
@@ -357,9 +355,14 @@ conjdbc=function(trat,
                                                         mean, na.rm=TRUE)[rownames(tukeyjuntos$groups)]}
         tukeyjuntos=tukeyjuntos$groups}
       if(mcomp=="sk"){
-        tukeyjuntos=sk(resp,tratamento,a$Df[1], a$`Sum Sq`[1],
-                              alpha = alpha.t)
-        colnames(tukeyjuntos)=c("resp","groups")
+        nrep=table(tratamento)[1]
+        medias=sort(tapply(resp,tratamento,mean),decreasing = TRUE)
+        letra=scottknott(means = medias,
+                         df1 = a$Df[1],
+                         nrep = nrep,
+                         QME = a$`Mean Sq`[1],
+                         alpha = alpha.t)
+        tukeyjuntos=data.frame(resp=medias,groups=letra)
         if(transf!="1"){tukeyjuntos$respo=tapply(response, tratamento,
                                                  mean, na.rm=TRUE)[rownames(tukeyjuntos)]}}
 
@@ -400,9 +403,8 @@ conjdbc=function(trat,
       cat("Multiple comparison test (",mcomp,")")
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       print(tukeyjuntos)
-      print(grafico1)
-      graficos=list(grafico1)}
-    if(quali==FALSE){grafico1=polynomial(tratnum,#as.numeric(as.character(tratamento)),
+      }
+    if(quali==FALSE){grafico1=polynomial(tratnum,
                                      response,grau = grau,
                                      textsize=textsize,
                                      family=family,
@@ -411,12 +413,13 @@ conjdbc=function(trat,
                                      theme=theme,
                                      posi="top",
                                      se=errorbar)
+    }
     graficos=list(grafico1)
   }
-  }
   cat(if(transf=="1"){}else{blue("\nNOTE: resp = transformed means; respO = averages without transforming\n")})
 
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test and try to transform the data"))}
   if(transf != 1 && norm1$p.value<0.05 | transf!=1 && indep$p.value<0.05 | transf!=1 && homog1$p.value<0.05){cat(red("\n \nWarning!!! Your analysis is not valid, suggests using a non-parametric test"))}
+  print(graficos)
   graph=as.list(graficos)
 }
